About
=====

Colorcet is completely open source, available under a `Creative Commons Attribution <https://github.com/holoviz/colorcet/blob/main/LICENSE.txt>`_ license freely for both commercial and non-commercial use. Colorcet was originally developed with the support of `Anaconda Inc. <https://anaconda.com>`_, and is now maintained by Anaconda developers and community contributors.

Colorcet is part of the `HoloViz <https://holoviz.org>`_ family of tools. The `holoviz.org <https://holoviz.org>`_ website shows how to use Colorcet together with other libraries to solve complex problems, with detailed tutorials and examples. You can see a variety of projects using Colorcet at `examples.pyviz.org <https://examples.pyviz.org>`_, and you can compare Colorcet to other available tools at `pyviz.org <https://pyviz.org>`_.

If you are interested in contributing to Colorcet development to help address some of the `open issues <https://github.com/holoviz/colorcet/issues>`_, see our `developer instructions <https://colorcet.holoviz.org/getting_started/index.html#developer-instructions>`_ to set up your development environment.

If you like Colorcet and have built something you want to share, tweet a link or screenshot of your latest creation at @HoloViz_org, along with any other library you used (@HoloViews, @Datashader, @Panel_org, @BokehPlots, @Matplotlib, etc.). Thanks!
